@@ -101,12 +101,14 @@ class GoogleAnalyticsTextProvider(TextProvider):
             now = datetime.date.today()
             self.start = datetime.date(year=now.year, month=now.month, day=1)
             self.end = datetime.date(year=now.year, month=now.month, day=now.day)
+            print self.start, self.end
 
-            prevmonth = (now.month + 11) % 12
+            prevmonth = now.month - 1 if now.month > 1 else 12
             lastdayofprevmonth = calendar.monthrange(now.year, prevmonth)[1]
             prevyear = now.year - 1 if prevmonth == 12 else now.year
             self.refstart = datetime.date(year=prevyear, month=prevmonth, day=1)
             self.refend = datetime.date(year=prevyear, month=prevmonth, day=lastdayofprevmonth)
+            print "=>", self.refstart, self.refend
         self.ga = ga
 
     def format_data(self, **kwargs):
