@@ -17,7 +17,10 @@ class SlideModelMixin:
         return self.picture
 
     def get_title(self):
-        return basename(self.get_picture().get_path())
+        try:
+            return basename(self.get_picture().get_path())
+        except:
+            return ""
 
 class SliderModelMixin:
     def get_slides(self):
